@@ -310,6 +310,15 @@ gnome_vfs_escape_slashes (const gchar *string)
 	return gnome_vfs_escape_string_internal (string, UNSAFE_SLASHES);
 }
 
+/**
+ * gnome_vfs_escape_set:
+ * @string: string to be escaped
+ * @match_set: a string containing all characters to be escaped in @string. 
+ *  
+ * Escapes all characters in @string which are listed in @match_set.  
+ * 
+ * Return value: a newly allocated and escaped string.
+ **/
 char *
 gnome_vfs_escape_set (const char *string,
 	              const char *match_set)
@@ -491,7 +500,7 @@ gnome_vfs_unescape_string (const gchar *escaped_string,
 }
 
 /**
- * gnome_vfs_unescape_for_display:
+ * gnome_vfs_unescape_string_for_display:
  * @escaped: The string encoded with escaped sequences
  * 
  * Similar to gnome_vfs_unescape_string, but it returns something
@@ -1021,11 +1030,13 @@ gnome_vfs_is_executable_command_string (const char *command_string)
  * Reads an entire file into memory for convenience. Beware accidentally
  * loading large files into memory with this function.
  *
+ * Since version 2.10 the string stored in @file_contents will be nul-terminated,
+ * so for text files you can use result as a normal string.
+ *
  * Return value: An integer representing the result of the operation
  *
  * Since: 2.2
  */
-
 GnomeVFSResult
 gnome_vfs_read_entire_file (const char *uri,
 			    int *file_size,
@@ -1037,10 +1048,10 @@ gnome_vfs_read_entire_file (const char *uri,
 	GnomeVFSFileSize total_bytes_read;
 	GnomeVFSFileSize bytes_read;
 
-	g_assert (file_size != NULL);
 	g_assert (file_contents != NULL);
 
-	*file_size = 0;
+	if (file_size != NULL)
+		*file_size = 0;
 	*file_contents = NULL;
 
 	/* Open the file. */
@@ -1074,6 +1085,9 @@ gnome_vfs_read_entire_file (const char *uri,
 		total_bytes_read += bytes_read;
 	} while (result == GNOME_VFS_OK);
 
+	buffer = g_realloc (buffer, total_bytes_read + 1);
+	buffer[total_bytes_read] = '\0';
+
 	/* Close the file. */
 	result = gnome_vfs_close (handle);
 	if (result != GNOME_VFS_OK) {
@@ -1082,8 +1096,9 @@ gnome_vfs_read_entire_file (const char *uri,
 	}
 
 	/* Return the file. */
-	*file_size = total_bytes_read;
-	*file_contents = g_realloc (buffer, total_bytes_read);
+	if (file_size != NULL)
+		*file_size = total_bytes_read;
+	*file_contents = g_realloc (buffer, total_bytes_read + 1);
 	return GNOME_VFS_OK;
 }
 
@@ -1485,7 +1500,7 @@ gnome_vfs_make_uri_from_input (const char *location)
  * Determines a fully qualified URL from a relative or absolute input path.
  * Basically calls gnome_vfs_make_uri_from_input except it specifically
  * tries to support paths relative to the specified directories (can be homedir
- * and/or current directory).
+ * and/or current directory). See #GnomeVFSMakeURIDirs for more information.
  *
  * Return value: a newly allocated string containing the fully qualified URL
  *
@@ -2159,19 +2174,19 @@ gnome_vfs_url_show_with_env (const char  *url,
 		return result;
 	}
 	
+	g_free (scheme);
+
 	type = _gnome_vfs_get_slow_mime_type (url);
 
 	if (type == NULL) {
-		g_free (scheme);
-		return GNOME_VFS_ERROR_BAD_PARAMETERS;
+		return GNOME_VFS_ERROR_NO_DEFAULT;
 	}
-
+	
 	params.data = (char *) url;
 	params.prev = NULL;
 	params.next = NULL;
-	
-	app = gnome_vfs_mime_get_default_application_for_scheme (type, scheme);
-	g_free (scheme);
+
+	app = gnome_vfs_mime_get_default_application_for_uri (url, type);
 	
 	if (app != NULL) {
 		result = gnome_vfs_mime_application_launch_with_env (app, &params, envp);
